from django.db import models
from django.utils.translation import gettext_lazy as _
from django.utils.safestring import mark_safe

# ImageFile model (unchanged)
class ImageFile(models.Model):
    image = models.ImageField(
        _("Изображение"),
        upload_to='photo/',
        null=True,
        blank=True
    )
    external_url = models.URLField(
        _("Внешняя ссылка на изображение"),
        max_length=500,
        null=True,
        blank=True
    )
    created_at = models.DateTimeField(_("Дата создания"), auto_now_add=True)

    class Meta:
        verbose_name = _("Изображение")
        verbose_name_plural = _("Изображения")

    def get_image_url(self):
        if self.image:
            return self.image.url
        elif self.external_url:
            return self.external_url
        return None

    def __str__(self):
        if self.image:
            return f"Локальное изображение: {self.image.name}"
        elif self.external_url:
            return f"Внешнее изображение: {self.external_url}"
        return _("Нет изображения")
    
    def image_tag(self):
        if self.image:
            return mark_safe(f'<img src="{self.image.url}" width="100" height="100" />')
        elif self.external_url:
            return mark_safe(f'<img src="{self.external_url}" width="100" height="100" />')
        return _("Нет изображения")

# Category model (unchanged)
class Category(models.Model):
    name = models.CharField(_("Название категории"), max_length=100)
    slug = models.SlugField(_("Слаг"), max_length=100, unique=True)
    created_at = models.DateTimeField(_("Дата создания"), auto_now_add=True)
    updated_at = models.DateTimeField(_("Дата обновления"), auto_now=True)

    class Meta:
        verbose_name = _("Категория")
        verbose_name_plural = _("Категории")

    def __str__(self):
        return self.name

# Portfolio model (unchanged)
class Portfolio(models.Model):
    name = models.CharField(_("Название проекта"), max_length=200)
    category = models.ForeignKey(
        Category,
        on_delete=models.SET_NULL,
        null=True,
        blank=True,
        verbose_name=_("Категория"),
        related_name="portfolios"
    )
    images = models.ManyToManyField(
        ImageFile,
        verbose_name=_("Изображения"),
        related_name="portfolios"
    )
    company = models.CharField(_("Компания"), max_length=200)
    description = models.TextField(_("Описание проекта"))
    start_date = models.DateField(_("Дата начала"), null=True, blank=True)
    end_date = models.DateField(_("Дата окончания"), null=True, blank=True)
    cost = models.DecimalField(
        _("Стоимость"),
        max_digits=10,
        decimal_places=2,
        null=True,
        blank=True
    )
    created_at = models.DateTimeField(_("Дата создания"), auto_now_add=True)
    updated_at = models.DateTimeField(_("Дата обновления"), auto_now=True)

    class Meta:
        verbose_name = _("Портфолио")
        verbose_name_plural = _("Портфолио")

    def __str__(self):
        return f"{self.name} ({self.company})"

    def get_primary_image_url(self):
        first_image = self.images.first()
        return first_image.get_image_url() if first_image else None

    def primary_image_tag(self):
        first_image = self.images.first()
        return first_image.image_tag() if first_image else _("Нет изображения")

from django.db import models
from django.utils.translation import gettext_lazy as _

class Order(models.Model):
    AD_TYPE_CHOICES = [
        ('outdoor', _('Наружная реклама')),
        ('digital', _('Digital')),
        ('branding', _('Брендинг')),
    ]

    ORDER_STATUS = [
        ('new', _('Новый')),
        ('in_review', _('На рассмотрении')),
        ('approved', _('Одобрен')),
        ('in_progress', _('В работе')),
        ('on_hold', _('На удержании')),
        ('completed', _('Завершен')),
        ('canceled', _('Отменен')),
    ]

    ad_type = models.CharField(
        _("Тип рекламы"),
        max_length=50,
        choices=AD_TYPE_CHOICES
    )
    project_description = models.TextField(_("Описание проекта"))
    budget = models.DecimalField(
        _("Бюджет"),
        max_digits=10,
        decimal_places=2
    )
    name = models.CharField(_("Имя"), max_length=100)
    email = models.EmailField(_("Email"))
    phone = models.CharField(_("Телефон"), max_length=15)
    status = models.CharField(
        _("Статус"),
        max_length=20,
        choices=ORDER_STATUS,
        default='new'
    )
    comments = models.TextField(
        _("Комментарии"),
        blank=True,
        null=True,
        help_text=_("Дополнительные заметки или комментарии по заказу")
    )
    created_at = models.DateTimeField(_("Дата создания"), auto_now_add=True)
    updated_at = models.DateTimeField(_("Дата обновления"), auto_now=True)

    class Meta:
        verbose_name = _("Заказ")
        verbose_name_plural = _("Заказы")

    def __str__(self):
        return f"Заказ от {self.name} ({self.email})"

    @classmethod
    def get_ad_type_choices(cls):
        """Returns AD_TYPE_CHOICES for use in templates."""
        return cls.AD_TYPE_CHOICES

    @classmethod
    def get_order_status_choices(cls):
        """Returns ORDER_STATUS choices for use in templates."""
        return cls.ORDER_STATUS